import subprocess
from pathlib import Path

# List of all legal MTEB datasets from the image
LEGAL_DATASETS = [
    "legal_summarization",
    "legalbench_corporate_lobbying",
    "legalbench_consumer_contracts_qa",
    "LegalQuAD"
]

def clone_and_zip_dataset(dataset_name: str):
    """Clone and zip a single dataset."""
    try:
        working_path = Path.cwd()
        print(f"\nProcessing {dataset_name}...")
        
        # Clone repository
        print(f"Cloning {dataset_name}...")
        subprocess.run(["git", "clone", f"https://huggingface.co/datasets/mteb/{dataset_name}"], check=True)
        
        # Create zip excluding .git
        print("Creating zip archive...")
        subprocess.run([
            "zip", "-r", 
            f"{dataset_name}.zip", 
            dataset_name,
            "-x", f"{dataset_name}/.git/*",
            f"{dataset_name}/.git*"
        ], check=True)
        
        # Clean up
        print("Cleaning up...")
        subprocess.run(["rm", "-rf", dataset_name], check=True)
        
        print(f"Successfully processed {dataset_name}")
        return True
        
    except subprocess.CalledProcessError as e:
        print(f"Error processing {dataset_name}: {str(e)}")
        return False
    except Exception as e:
        print(f"Unexpected error processing {dataset_name}: {str(e)}")
        return False

def main():
    """Process all legal MTEB datasets."""
    results = []
    
    for dataset in LEGAL_DATASETS:
        success = clone_and_zip_dataset(dataset)
        results.append((dataset, success))
    
    # Print summary
    print("\nProcessing Summary:")
    print("==================")
    for dataset, success in results:
        status = "✓ Success" if success else "✗ Failed"
        print(f"{dataset}: {status}")

if __name__ == "__main__":
    main()
